package com.chinaitop.depot.grainSituationCard.controller;

import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageDailycheck;
import com.chinaitop.depot.grainSituationCard.service.StorageDailyCardService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 2020/7/16
 * jidongjie
 */
@RestController
@RequestMapping(value = "/dailyCard")
@Api(value = "StorageDailyCardController", description = "日常检查卡")
public class StorageDailyCardController {
    private final static Logger logger = LoggerFactory.getLogger(StorageDailyCardController.class);

    @Resource
    private StorageDailyCardService dailyCardService;

    /**
     * 粮情卡分页列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param warehouseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findDailyList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据仓房号和货位号查询", notes = "查询质量记录,分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "组织机构编码", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "组织机构编码", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity findDailyList(Integer pageNum, Integer pageSize, Integer houseId, Integer warehouseId, Integer orgId) {
        List<StorageDailycheck> dailyCardList = null;
        try {
            if (houseId == null) {
                return ResponseEntity.failed("仓房机构为空!");
            }
            if (warehouseId == null) {
                return ResponseEntity.failed("货位机构为空!");
            }
            if (orgId == null) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            dailyCardList = dailyCardService.findDailyList(houseId, warehouseId, orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<StorageDailycheck> pageInfo = new PageInfo<>(dailyCardList);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/findDailyCardList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询日常检查记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "粮情卡id", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public Map<String, Object> findDailyCardList(String id, Integer houseId,Integer warehouseId,String orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        try {
            if (StringUtils.isNotBlank(id)) {
                map = dailyCardService.findDailyCardList(id, orgId,houseId,warehouseId);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return map;
    }

    /**
     * 保存 区分字段 flag_type = '1' // 提交 区分字段 flag_type = '2'
     * @param dailyCard
     * @param dailyCardOne
     * @param dailyCardTwo
     * @param flagType
     * @param cardNum
     * @param houseId
     * @param warehouseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/saveAndCommit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存,提交接口", notes = "保存提交")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dailyCard", value = "json字符串数组", paramType = "query"),
            @ApiImplicitParam(name = "dailyCardOne", value = "json字符串数组", paramType = "query"),
            @ApiImplicitParam(name = "dailyCardTwo", value = "json字符串数组", paramType = "query"),
            @ApiImplicitParam(name = "flagType", value = "保存:1,提交:2", paramType = "query"),
            @ApiImplicitParam(name = "cardNum", value = "主表id", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity saveAndCommit(String dailyCard,String dailyCardOne,String dailyCardTwo,Integer flagType, String cardNum,Integer houseId,Integer warehouseId, Integer orgId) {
        // 返回语
        String str = "";
        try {
            if (flagType == null) {
                return ResponseEntity.failed("标识不能为空!");
            }
            if (orgId == null) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            //保存:1,提交:2
            dailyCardService.saveAndCommit(dailyCard, dailyCardOne, dailyCardTwo, flagType, orgId , cardNum, houseId, warehouseId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok(str);
    }

    /**
     * 根据id删除
     * @param id
     * @return
     */
    @RequestMapping(value = "/deleteDailyCardById", method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询质量记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "主表id", paramType = "query")
    })
    public ResponseEntity deleteDailyCardById(Integer type,String id) {
        try {
            dailyCardService.deleteDailyCardById(type,id);

            return ResponseEntity.ok();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("删除失败!");
    }


}
