package com.chinaitop.depot.grainSituationCard.controller;

import com.alibaba.fastjson.JSONArray;
import com.chinaitop.depot.grainSituationCard.service.SystemOutsideDataService;
import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageGrainCard;
import com.chinaitop.depot.grainSituationCard.model.StorageQualitycheckCard;
import com.chinaitop.depot.grainSituationCard.service.StorageGrainCardService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 粮情卡列表页
 * @create 2020-07-02 19:55
 */
@RestController
@RequestMapping(value = "/grainCard")
@Api(value = "StorageGrainCardController", description = "粮情卡-主页")
@SuppressWarnings("all")
public class StorageGrainCardController {
    private final static Logger logger = LoggerFactory.getLogger(StorageGrainCardController.class);
    @Resource
    private StorageGrainCardService grainCardService;
    
    @Resource
	private SystemOutsideDataService systemOutsideDataService;

    @RequestMapping(value = "/chooseStoreAndHouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询粮情卡列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "组织机构编码", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "组织机构编码", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "storehouseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query"),
            @ApiImplicitParam(name = "sfgd", value = "是否归档(1:否,0:是)", paramType = "query")
    })
    public ResponseEntity chooseStoreAndHouse(Integer pageNum, Integer pageSize, Integer storehouseId, Integer warehouseId,
                                              String createTime, String orgId, String sfgd,Integer qualitycheckId) {
        List<StorageGrainCard> list = null;
        PageInfo<StorageGrainCard> pageInfo = null;
        try {
            if (StringUtils.isBlank(orgId)) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = grainCardService.getList(storehouseId, warehouseId, createTime, orgId, sfgd,qualitycheckId);
            pageInfo = new PageInfo<>(list);
        } catch (Exception e) {
            e.printStackTrace();
        }


        return ResponseEntity.ok(pageInfo);
    }

    /**
     * 接收市平台数据接口-保存粮情卡主列表页,保存市平台审批通过数据
     *
     * @param grainCards
     * @return
     */
    @RequestMapping(value = "/saveData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "接收市平台数据接口", notes = "保存粮情卡主列表页")
    @ApiImplicitParam(name = "grainCards", value = "json字符串", paramType = "query")
    public ResponseEntity saveData(String grainCards) {
        Map<String, Object> check_map = new HashMap<>();
        try {
            // 接收数据
            logger.info(grainCards);
            // json字符串转对象
            if (StringUtils.isNotBlank(grainCards)) {
                List<StorageGrainCard> storageGrainCards = JSONArray.parseArray(grainCards, StorageGrainCard.class);
                //先校验数据库是否合法
                 check_map = grainCardService.saveData(storageGrainCards);
                logger.info("接收市平台数据接口，数据校验结果是："+check_map.toString());
                systemOutsideDataService.addlogger("lqkjs", grainCards, check_map.toString());
//                if (!"success".equals(map.get("status"))) {
//                    grainCardService.saveData(storageGrainCards);
//                }
            }
        } catch (Exception e) {
        	check_map.put("status", "error");
        	check_map.put("msg", "接口异常，请联系管理员！");
            logger.error(e.getMessage(), e);
            systemOutsideDataService.addlogger("lqkjs", grainCards, check_map.toString());
        }
        return ResponseEntity.ok(check_map);
    }

    /**
     * 更新粮情卡数据接口
     *
     * @param grainCard
     * @return
     */
    @RequestMapping(value = "/updateData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "更新粮情卡数据接口", notes = "更新粮情卡主列表")
    @ApiImplicitParam(name = "grainCard", value = "json字符串", paramType = "form")
    public ResponseEntity updateData(String grainCard) {
        try {
            // 接收数据
            logger.info(grainCard);
            // json字符串转对象
            if (StringUtils.isNotBlank(grainCard)) {
                StorageGrainCard grainCardWithBLOBs = JSONArray.parseObject(grainCard, StorageGrainCard.class);
                grainCardService.updateData(grainCardWithBLOBs);
            }
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/findGrainCard", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询粮情卡对应的质检数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "自检数据id", paramType = "query")
    })
    public Map<String, Object> findGrainCard(Integer id) {
        Map<String, Object> map = new HashMap<String, Object>();
        try {
            if (id == null) {
                map.put("status", "error");
                map.put("msg", "自检数据ID不能为空");
                return map;
            }
            map = grainCardService.getGrainCard(id);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return map;
    }

    /**
     * 根据id获取原粮粮情卡数据.
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/findGrainCardById", method = RequestMethod.GET)
    @ApiOperation(value = "根据id查询粮情卡", notes = "查询粮情卡单条数据")
    @ApiImplicitParam(name = "id", value = "id编码", paramType = "query")
    public ResponseEntity findGrainCardById(String id) {
        StorageGrainCard card = null;
        try {
            if (StringUtils.isBlank(id)) {
                return ResponseEntity.failed("id编码不能为空!");
            }
            card = grainCardService.findGrainCardById(id);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok(card);
    }

    /**
     * @param id
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findQuailckCard", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询质量记录")
    @ApiImplicitParam(name = "id", value = "粮情卡id", paramType = "query")
    public ResponseEntity findQuailckCardList(String id, String orgId) {
        List<StorageQualitycheckCard> tempCardList = null;
        try {
            if (StringUtils.isNotBlank(id)) {
                tempCardList = grainCardService.findQuailckCardList(id, orgId);
            }
            return ResponseEntity.ok(tempCardList);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("粮情卡编码不能为空!");
    }

    @RequestMapping(value = "/saveGrainOilCardData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存方法(手动补录)")
    @ApiImplicitParam(name = "grainCard", value = "json字符串", paramType = "query")
    public ResponseEntity saveGrainOilCardData(String grainCard) {
        try {
            // 接收数据
            logger.info(grainCard);
            // json字符串转对象
            if (StringUtils.isNotBlank(grainCard)) {
                StorageGrainCard grainOil = JSONArray.parseObject(grainCard, StorageGrainCard.class);
                grainCardService.saveGrainOilCardData(grainOil);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok();
    }

    /**
     * 查询质量检验生产年度
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findQualityCheckScnd", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询生产年度", notes = "查询质量生产年度")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织编码", paramType = "query"),
            @ApiImplicitParam(name = "parentId", value = "字典父级id", paramType = "query")
    })
    public ResponseEntity findQualityCheckScnd(Integer houseId, Integer warehouseId, String orgId, Integer parentId) {
        try {
            if (null != houseId && StringUtils.isNotBlank(orgId)) {
                Map<String, Object> scnd = grainCardService.findQualityCheckScnd(houseId, warehouseId, orgId, parentId);
                return ResponseEntity.ok(scnd);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("仓房编码不能为空!");
    }

    /**
     * 卡id删除所有主表和子表数据(已保存未提交的数据)
     * @param id
     * @return
     */
    @RequestMapping(value = "/gainOilCardAllDelete", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询生产年度", notes = "查询质量生产年度")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "卡id删除", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织编码", paramType = "query")
    })
    public ResponseEntity gainOilCardAllDelete(String id, String orgId) {
        try {
            if (StringUtils.isNotBlank(id)) {
                grainCardService.gainOilCardAllDelete(id, orgId);
                return ResponseEntity.ok("删除成功!");
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("删除失败!");
        }
        return ResponseEntity.failed("删除失败!");
    }

    /**
     * 查询所有的仓房和油罐
     *
     * @param storehouse
     * @param house
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/selectAndOrgId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询所有的仓房和油罐", notes = "查询所有的仓房和油罐")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity selectAndOrgId(String orgId) {
        List<StorageGrainCard> list = null;
        try {
            if (StringUtils.isBlank(orgId)) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            list = grainCardService.selectAndOrgId(orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return ResponseEntity.ok(list);
    }
}
