package com.chinaitop.depot.grainSituationCard.controller;

import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageOverDueAlarmView;
import com.chinaitop.depot.grainSituationCard.service.StorageOverDueAlarmService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 储存超限报警
 * 只做原粮的就行
 * @author aihua
 * @date 2022-04-16 15:50
 */
@RestController
@RequestMapping("/overDueAlarm")
@Api(value = "StorageOverDueAlarmController", description = "储存超限告警-主页")
public class StorageOverDueAlarmController {

    @Autowired
    private StorageOverDueAlarmService storageOverDueAlarmService;

    @RequestMapping(value = "/getOverDueAlarmList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "储存超限报警查询", notes = "查询储存超限报警列表,支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "起始页", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "页面大小", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity<PageInfo<StorageOverDueAlarmView>> getOverDueAlarmList(Integer pageNum, Integer pageSize, String orgId) {
        if (StringUtils.isBlank(orgId)) {
            return ResponseEntity.failed("组织机构编码不能为空!");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageOverDueAlarmView> list = storageOverDueAlarmService.getAlarmList(orgId);
        PageInfo<StorageOverDueAlarmView> pageInfo = new PageInfo<>(list);
        // 不使用sql执行分页时StartRow和EndRow使用的索引0-N,为显示效果需要索引+1.
        if (pageInfo.getTotal() > 0) {
            // 显示页加1
            pageInfo.setStartRow(pageInfo.getStartRow() + 1);
            pageInfo.setEndRow(pageInfo.getEndRow() + 1);
        }
        return ResponseEntity.ok(pageInfo);


    }
}
