package com.chinaitop.depot.grainSituationCard.controller;

import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageQualitycheckCard;
import com.chinaitop.depot.grainSituationCard.service.StorageQualityCardService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * 2020/7/16
 * jidongjie
 */
@RestController
@RequestMapping(value = "/qualityCard")
@Api(value = "StorageQualityCardController", description = "质量卡")
public class StorageQualityCardController {
    private final static Logger logger = LoggerFactory.getLogger(StorageQualityCardController.class);

    @Resource
    private StorageQualityCardService qualityCardService;

    /**
     * 粮情卡分页列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param warehouseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findQualityList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据仓房号和货位号查询", notes = "查询质量记录,分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "组织机构编码", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "组织机构编码", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity findQualityList(Integer pageNum, Integer pageSize, Integer houseId, Integer warehouseId, Integer orgId) {
        List<StorageQualitycheckCard> qualityCardList = null;
        try {
            if (houseId == null) {
                return ResponseEntity.failed("仓房机构为空!");
            }
            if (orgId == null) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            qualityCardList = qualityCardService.findQualityList(houseId, warehouseId, orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<StorageQualitycheckCard> pageInfo = new PageInfo<>(qualityCardList);
        return ResponseEntity.ok(pageInfo);
    }

    /**
     * 保存 区分字段 flag_type = '1' // 提交 区分字段 flag_type = '2'
     * @param qualityCard
     * @param flagType
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/saveAndCommit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存,提交接口", notes = "保存提交")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualityCard", value = "json字符串数组", paramType = "query"),
            @ApiImplicitParam(name = "flagType", value = "保存:1,提交:2", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query"),
            @ApiImplicitParam(name = "cardNum", value = "主表id", paramType = "query")
    })
    public ResponseEntity saveAndCommit(String qualityCard,Integer flagType, Integer orgId,String cardNum) {
        logger.info(qualityCard);
        // 返回语
        String str = "";
        try {
            if (StringUtils.isBlank(qualityCard)) {
                return ResponseEntity.failed("数据不能为空!");
            }
            if (flagType == null) {
                return ResponseEntity.failed("标识不能为空!");
            }
            if (orgId == null) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if(StringUtils.isBlank(cardNum)){
                return ResponseEntity.failed("主表id不能为空!");
            }
            //保存:1,提交:2
           qualityCardService.saveAndCommit(qualityCard, flagType, orgId , cardNum);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok(str);
    }

    /**
     * 根据id删除
     * @param id
     * @return
     */
    @RequestMapping(value = "/deleteQualityCardById", method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询质量记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主表id", paramType = "query")
    })
    public ResponseEntity deleteQualityCardById(Integer id) {
        try {
            if (id != null) {
                qualityCardService.deleteQualityCardById(id);
            }
            return ResponseEntity.ok();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("删除失败!");
    }

}
