package com.chinaitop.depot.grainSituationCard.controller;

import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageTempCard;
import com.chinaitop.depot.grainSituationCard.service.StorageTempCardService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author qingsong.han
 * @description: 粮食温度
 * @create 2020-06-28 15:19
 */
@RestController
@RequestMapping(value = "/grainTemperature")
@Api(value = "StorageTempCardController", description = "粮情卡-测温")
public class StorageTempCardController {
    private final static Logger logger = LoggerFactory.getLogger(StorageTempCardController.class);
    @Resource
    private StorageTempCardService tempCardService;

    // TODO 建议分页未添加

    /**
     * 粮温测量记录-添加测温卡数据
     *
     * @param storehouse 不能为空
     * @param house      不能为空
     * @param orgId      不能为空
     * @return
     */
    @RequestMapping(value = "/findByStorehouseAndHouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据仓房号和货位号查询", notes = "查询测温记录,分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "组织机构编码", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "组织机构编码", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "storehouse", value = "仓房编码", paramType = "query"),
            @ApiImplicitParam(name = "house", value = "货位编码", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity findByStorehouseAndHouse(Integer pageNum, Integer pageSize, String storehouse, String house, String orgId) {
        List<StorageTempCard> tempCard = null;
        try {
            if (StringUtils.isBlank(storehouse)) {
                return ResponseEntity.failed("仓房编码不能为空!");
            }
            if (StringUtils.isBlank(orgId)) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            tempCard = tempCardService.findByStorehouseAndHouse(storehouse, house, orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<StorageTempCard> pageInfo = new PageInfo<>(tempCard);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/findTempCardList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询原粮粮情卡下：温度测量记录页签数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "粮情卡id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织编码", paramType = "query"),
            @ApiImplicitParam(name = "sortFlag", value = "排序标记(1正序)", paramType = "query")
    })
    public ResponseEntity findTempCardList(String id, String orgId, String sortFlag) {
        List<StorageTempCard> tempCardList = null;
        try {
            if (StringUtils.isNotBlank(id)) {
                tempCardList = tempCardService.findTempCardList(id, orgId, sortFlag);
            }
            return ResponseEntity.ok(tempCardList);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("测温卡编码不能为空!");
    }

    /**
     * 保存 区分字段 flag_type = '1' // 提交 区分字段 flag_type = '2'
     *
     * @param tempCards
     * @param flagType
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/saveAndCommit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存,提交接口", notes = "保存提交")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "tempCards", value = "json字符串数组", paramType = "query"),
            @ApiImplicitParam(name = "flagType", value = "保存:1,提交:2", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity saveAndCommit(String tempCards, String flagType, String orgId) {
        logger.info(tempCards);
        // 返回语
        String str = "";
        try {
            if (StringUtils.isBlank(tempCards)) {
                return ResponseEntity.failed("数据不能为空!");
            }
            if (StringUtils.isBlank(flagType)) {
                return ResponseEntity.failed("标识不能为空!");
            }
            if (StringUtils.isBlank(orgId)) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            //保存:1,提交:2
            tempCardService.saveAndCommit(tempCards, flagType, orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok(str);
    }

    /**
     * 根据id删除
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/deleteTempCardById", method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询测温记录")
    @ApiImplicitParam(name = "id", value = "粮情卡id", paramType = "query")
    public ResponseEntity deleteTempCardById(String id) {
        try {
            if (StringUtils.isNotBlank(id)) {
                int r = tempCardService.deleteTempCardById(id);
                if (r > 0) {
                    return ResponseEntity.ok();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.failed("删除失败!");
    }

    // 五温图
    public ResponseEntity fiveTempDrawData() {
        return null;
    }

}
