package com.chinaitop.depot.grainSituationCard.service.impl;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Random;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.common.EnumUtils;
import com.chinaitop.depot.common.UuidUtils;
import com.chinaitop.depot.config.DateUtil;
import com.chinaitop.depot.feign.BasicWarehouseFeignClient;
import com.chinaitop.depot.feign.FeignBusinessService;
import com.chinaitop.depot.grainSituationCard.mapper.StorageChangeStoragehouseRopMapper;
import com.chinaitop.depot.grainSituationCard.mapper.StorageGrainCardMapper;
import com.chinaitop.depot.grainSituationCard.mapper.StorageQualitycheckMapper;
import com.chinaitop.depot.grainSituationCard.model.StorageChangeStoragehouseRop;
import com.chinaitop.depot.grainSituationCard.model.StorageChangeStoragehouseRopExample;
import com.chinaitop.depot.grainSituationCard.model.StorageGrainCard;
import com.chinaitop.depot.grainSituationCard.model.StorageGrainCardExample;
import com.chinaitop.depot.grainSituationCard.model.StorageGrainView;
import com.chinaitop.depot.grainSituationCard.model.StorageOverRunAlarm;
import com.chinaitop.depot.grainSituationCard.model.StorageQualitycheckCard;
import com.chinaitop.depot.grainSituationCard.service.StorageGrainCardService;
import com.chinaitop.depot.grainSituationCard.service.StorageOverRunAlarmService;

/**
 * @author qingsong.han
 * @description:
 * @create 2020-07-02 20:08
 */
@Service
public class StorageGrainCardServiceImpl implements StorageGrainCardService {
    private final static Logger logger = LoggerFactory.getLogger(StorageGrainCardServiceImpl.class);
    @Resource
    private StorageGrainCardMapper grainCardMapper;
    @Resource
    private StorageChangeStoragehouseRopMapper storagehouseRopdMapper;
    @Resource
    private StorageQualitycheckMapper qualitycheckMapper;

    @Resource
    private BasicWarehouseFeignClient warehouseFeignClient;

    @Resource
    private StorageOverRunAlarmService storageOverRunAlarmService;

    @Resource
	private FeignBusinessService FeignBusinessService;
    
    @Resource
    private RestTemplate restTemplate;

    @Bean
    public RestTemplate restTemplate() {
        return new RestTemplate();
    }
    
    /**
     * 选择仓房货位查询列表信息,分页.
     *
     * @param storehouseId
     * @param warehouseId
     * @param orgId
     * @param sfgd 是否归档(1:否,0:是)
     * @return
     */
    @Override
    public List<StorageGrainCard> getList(Integer storehouseId, Integer warehouseId, String createTime, String orgId, String sfgd,Integer qualitycheckId) {
        // 查询所有条件数据
        StorageGrainCardExample grainCardExample = new StorageGrainCardExample();
        StorageGrainCardExample.Criteria criteria = grainCardExample.createCriteria();
        //criteria.andSfgdEqualTo("1"); //默认查询未归档的数据
        List<String> query_v = new ArrayList<>();
        query_v.add("1");//只查询满仓的，不是满仓，则说明没达到封仓条件，页面上不展示
        //query_v.add("2");//倒仓移库的
        criteria.andSfmcIn(query_v);
        if (null != storehouseId) {
            criteria.andStorehouseIdEqualTo(storehouseId);
        }
        if (null != warehouseId) {
            criteria.andWarehouseIdEqualTo(warehouseId);
        }
        if (null != qualitycheckId) {
            criteria.andQualitycheckIdEqualTo(qualitycheckId);
        }
        if (StringUtils.isNotBlank(createTime)) {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
//            criteria.andAcceptDateGreaterThan(date);
            criteria.andAcceptDateLessThan(date);
        }
        if (StringUtils.isNotBlank(sfgd)) {
            criteria.andSfgdEqualTo(sfgd);
        }
        criteria.andOrgIdEqualTo(orgId);
        grainCardExample.setOrderByClause("accept_date desc");
        List<StorageGrainCard> storageGrainCards = grainCardMapper.selectByExample(grainCardExample);

        return storageGrainCards;
    }

    /**
     * 保存市平台审批通过数据 RequestAgile
     *
     * @param storageGrainCards
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Map<String, Object> saveData(List<StorageGrainCard> storageGrainCards) throws Exception {
    	Map<String, Object> check_map = new HashMap<>();
    	
    	StorageGrainCard grainCard = null;
        // 传给出入库数据List初始
        List<Map<String, Object>> wareList = new ArrayList<>();

        // 初始通过批号
        Random random = new Random();
        String tgph = UuidUtils.getCode() + random.nextInt();
//        String ywlx = "";
        for (int i = 0; i < storageGrainCards.size(); i++) {
        	grainCard = storageGrainCards.get(i);
            // 添加id
            grainCard.setId(UuidUtils.getCode());
            // 根据市级货位编码转库级数据
            String hwbm = grainCard.getHwbm();
            // 仓房货位基础对象
            StorageGrainCard grainCardKG;
            // 初始参数,保存转换使用并在保存成功后调用接口,参数传给出入库模块
            Integer storehouseId;
            Integer warehouseId;
            String orgId;
            if (StringUtils.isNotBlank(hwbm)) {
                
            	//校验数据合法性
            	check_map = this.checkData(grainCard);
            	if (!"success".equals(check_map.get("status"))) {
            		break;
            	}
            	// 查询获取市平台转换库级后的数据
            	grainCardKG = (StorageGrainCard) check_map.get("grainCardKG");
            	// 提前获取(仓房id,货位id,组织id)
                storehouseId = grainCardKG.getStorehouseId();
                warehouseId = grainCardKG.getWarehouseId();
                orgId = grainCardKG.getOrgId();
                
            	//不要sfmc等于0的数据不要了
                if (!"0".equals(grainCard.getSfmc())) {
                	grainCard.setSfgd("0");//只要不是不满仓的数据都是未归档状态
                    // 查询到的数据放入保存对象
                    grainCard.setOrgId(orgId);
                    grainCard.setStorehouseNum(grainCardKG.getStorehouseNum());
                    grainCard.setStorehouseName(grainCardKG.getStorehouseName());
                    grainCard.setWarehouseNum(grainCardKG.getWarehouseNum());
                    grainCard.setWarehouseName(grainCardKG.getWarehouseName());
                    grainCard.setStorehouseId(storehouseId);
                    grainCard.setWarehouseId(warehouseId);

                    //挂载入库自检数据
                    String qualitycheckId = check_map.get("qualitycheckId")+"";
                    grainCard.setQualitycheckId(Integer.parseInt(qualitycheckId.trim()));

                    
                     // 验收类型(0:入库验收,1:倒仓验收,2:移库验收)
                     // 入库接收分批数据(使用生产年度和是否满仓区分是否一批数据),倒仓,移库(使用批号)
                     
                    if ("0".equals(grainCard.getCheckTypeNum())) {
                        // 获取已保存的入库批号
                        Map<String, Object> map = new HashMap<>();
                        map.put("orgId", grainCard.getOrgId());
                        map.put("hwbm", grainCard.getHwbm());
                        map.put("scnd", grainCard.getScnd());
                        String beforeTgph = grainCardMapper.getTgph(map);
                        if (StringUtils.isNotBlank(beforeTgph)) {
                            grainCard.setTgph(beforeTgph);
                        } else {
                            grainCard.setTgph(tgph);
                        }

                    } else {
                        grainCard.setTgph(tgph);
                    }

                    //构建刷新出入库状态的数据
                    Map<String, Object> wareMap = new HashMap<>();
                    wareMap.put("wareId", grainCardKG.getWarehouseId()); // 货位id
                    // 赋值出入库状态标记(1空仓,2入库中,3封仓,4出库中,9其它)
                    if ("1".equals(grainCard.getSfmc())) {//满仓的时候
                    	grainCard.setSfgd("1");
                    	wareMap.put("crk_status", "3");
                    } else if ("2".equals(grainCard.getSfmc())) {//其它情况的时候，并且还不是满仓
                    	wareMap.put("crk_status", "2");
                    	grainCard.setSfgd("0");
                    	grainCard.setGdsj(new Date());
                    }
                    wareMap.put("orgId", grainCardKG.getOrgId()); // 组织机构id
                    wareMap.put("lylx", "0");//这里的默认都是原粮
                    int str = grainCard.getStorehouseNum().indexOf("YG");
                    if (str == -1 ) {
                        wareMap.put("ywlx", "0");//粮食
                    } else {
                        wareMap.put("ywlx", "1");//油罐
                    }
                    wareList.add(wareMap);

                    // 封仓时比对「设计仓容」和「库存数量」，库存数量 ＞ 设计仓容时，生成告警 by AiHua 2022-04-15
                    generatorAlarm(grainCard);
                    
                    // 保存
                    grainCardMapper.insertSelective(grainCard);
                    //保证每个仓房货位下的数据只有一条粮情卡
                    if ("1".equals(grainCard.getSfmc())) {
                    	this.updateByExampleSelective(grainCard);
                    }
                }
                /*
                 * 性质转变单新增数据
                */
                logger.info("传给business的数据为: orgId：" + orgId+"storehouseId："+storehouseId+"warehouseId:"+warehouseId+"grainCard.getGrainVarietyName():"+
                		grainCard.getGrainVarietyName()+"grainCard.getRksl():"+grainCard.getRksl()+"grainCard.getLsxzzbdh():"+grainCard.getLsxzzbdh());
               String grainVarietyName = grainCard.getGrainVarietyName();
               BigDecimal rksl = grainCard.getRksl();
               String lsxzzbdh = grainCard.getLsxzzbdh();
               String xyh = grainCard.getSpareOne();//协议号
               //FeignBusinessService.saveDataRk(orgId,storehouseId,warehouseId,grainVarietyName,rksl,lsxzzbdh);
               
               /**
                * restTemplate调用
                */
               //String url = "http://localhost:9002/depot/business/receiveNotice/saveDataRkByRest";
               String url = "http://10.223.3.62:9002/depot/business/receiveNotice/saveDataRkByRest";//生产环境
               //String url = "http://172.16.0.16:9002/depot/business/receiveNotice/saveDataRkByRest";//测试环境
               
               // 请求头设置,x-www-form-urlencoded格式的数据
               HttpHeaders headers = new HttpHeaders();
               headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);

               //提交参数设置
               MultiValueMap<String, String> mapRest = new LinkedMultiValueMap<>();
               mapRest.add("orgId", orgId.toString());
               mapRest.add("storehouseId", storehouseId.toString());
               mapRest.add("warehouseId", warehouseId.toString());
               mapRest.add("grainVarietyName", grainVarietyName);
               mapRest.add("rksl", rksl.toString());
               mapRest.add("lsxzzbdh", lsxzzbdh);
               mapRest.add("xyh", xyh);
               
               // 组装请求体
               HttpEntity<MultiValueMap<String, String>> request = new HttpEntity<MultiValueMap<String, String>>(mapRest, headers);
                           
               // 发送post请求，并打印结果，以String类型接收响应结果JSON字符串
               String result = restTemplate.postForObject(url, request, String.class);
               System.out.println("restTemplate传参结果入库验收增加性质转变单"+result);
                		
            }
        }

        // 刷新出入库状态
        String wareJson = JSON.toJSONString(wareList);
        logger.info("传入库级basicWarehouse: " + wareJson);
        warehouseFeignClient.updateWarehouseCrkStatus(wareJson);

        return check_map;
    }

    public Map<String, Object> checkData(StorageGrainCard grainCard) throws Exception {
        Map<String, Object> map = new HashMap<>();

		String lypz = grainCard.getGrainVarietyNum();
        String ywlx = "";

        if (StringUtils.isBlank(lypz)) {//非空校验
            map.put("status", "error");
            map.put("msg", "grainVarietyNum值不合法，粮油品种编码不能为空！");
            return map;
        }
        if (lypz.length() < 3 || (lypz.length() > 3 && lypz.length() < 7) || lypz.length() > 7) {
            map.put("status", "error");
            map.put("msg", "grainVarietyNum值不合法，粮油品种编码的长度为3位或7位！");
            return map;
        }
        if (lypz.length() == 7) {
            lypz = lypz.substring(3, 7);
            if (!lypz.equals("0000")) {
                map.put("status", "error");
                map.put("msg", "grainVarietyNum值不合法，请传粮油品种大类！");
                return map;
            }
        }
        StorageGrainCard grainCardKG= null;
        String strs = grainCard.getHwbm().substring(0, 3);
        if ("120".equals(strs)) {
            ywlx = "0";
            grainCardKG = grainCardMapper.selectConvertCfData(grainCard.getHwbm());
        } else {
            ywlx = "1";
            grainCardKG = grainCardMapper.selectConvertYgData(grainCard.getHwbm());
        }

        String qualitycheckId = getQualityCheckId(grainCard.getScnd(), grainCard.getGrainVarietyNum(), grainCardKG.getOrgId(), grainCard.getStorehouseId(), grainCard.getWarehouseId(), ywlx);
        if (StringUtils.isBlank(qualitycheckId)) {
        	map.put("status", "error");
            map.put("msg", "没有找到可挂载的自检入库验收数据！");
            return map;
        }

        map.put("qualitycheckId", qualitycheckId);
        map.put("ywlx", ywlx);
        map.put("grainCardKG", grainCardKG);

        map.put("status", "success");
        map.put("msg", "数据合法！");

        return map;
    }

    /**
     * 封仓时比对「设计仓容」和「库存数量」，库存数量 ＞ 设计仓容时，生成告警
     * @param grainCard 原粮卡
     */
    private void generatorAlarm(StorageGrainCard grainCard) {
        Integer storehouseId = grainCard.getStorehouseId();
        BigDecimal designCapacity = storageOverRunAlarmService.getStoreDesignCapacityById(storehouseId);
        // 设计仓容 < 库存数量
        if (designCapacity != null && designCapacity.compareTo(grainCard.getRksl()) < 0) {
            logger.info("generator storage overrun alarm store house designCapacity :[{}], into store quantity :[{}]", designCapacity, grainCard.getRksl());
            Map<String, Object> dictionaryData = grainCardMapper.findDictionaryData(grainCard.getQualitycheckId());
            Integer levelEnumId = (Integer) dictionaryData.get("levelUpdate");
            Integer qualityId = Integer.parseInt((String) dictionaryData.get("quality"));
            String level = storageOverRunAlarmService.findByEnum(levelEnumId);
            String quality = storageOverRunAlarmService.findByEnum(qualityId);

            StorageOverRunAlarm alarm = new StorageOverRunAlarm();
            alarm.setId(UuidUtils.getCode());
            alarm.setStoreHouseId(storehouseId);
            alarm.setGrainOilName(grainCard.getGrainVarietyName());
            // 粮油性质
            alarm.setGrainOilQuality(quality);
            alarm.setInventoryQuantity(grainCard.getRksl().multiply(new BigDecimal(1000)).toString());
            alarm.setDesignCapacity(designCapacity.multiply(new BigDecimal(1000)).toString());
            // 等级
            alarm.setLevel(level);
            alarm.setOrgId(Integer.parseInt(grainCard.getOrgId()));
            alarm.setAlarmTime(DateUtil.getNow());
            alarm.setCreateTime(DateUtil.getNow());
            storageOverRunAlarmService.insertStorageAlarm(alarm);
        }
    }

    @Override
    public void updateData(StorageGrainCard grainCard) {
        grainCardMapper.updateByPrimaryKeySelective(grainCard);
    }

    @Override
    public Map<String, Object> getGrainCard(Integer id) {
        Map<String, Object> map = new HashMap<String, Object>();

        //查询原粮卡的全部数据
        StorageGrainView storageGrainView = new StorageGrainView();
        if (id != null) {
            storageGrainView.setQualitycheckId(id);
        }
        List<StorageGrainView> cardOnetList = grainCardMapper.selectGrainCardList(storageGrainView);
        map.put("cardOnetList", cardOnetList);

        return map;
    }

    public void show(Integer storehouse, Integer Warehouse, String orgId, List<StorageChangeStoragehouseRop> listAll) {
        StorageChangeStoragehouseRopExample grainCardExample = new StorageChangeStoragehouseRopExample();
        StorageChangeStoragehouseRopExample.Criteria criteria = grainCardExample.createCriteria();
        if (storehouse != null) {
            criteria.andOutStorehouseEqualTo(storehouse);
        }
        if (Warehouse != null) {
            criteria.andOutWarehouseEqualTo(Warehouse);
        }
        criteria.andOrgIdEqualTo(Integer.valueOf(orgId));
        List<StorageChangeStoragehouseRop> manyList = storagehouseRopdMapper.selectByExample(grainCardExample);
        listAll.addAll(manyList);
        if (manyList.size() > 0) {
            //仓房1 货位1.1  --> 倒仓 仓房2 货位2.2 --> 又倒仓 仓房1 货位1.1 会死循环。
            for (StorageChangeStoragehouseRop shr : listAll) {
                if (shr.getOutStorehouse().equals(manyList.get(0).getIntoStorehouse()) && shr.getOutWarehouse().equals(manyList.get(0).getIntoWarehouse())) {
                    return;
                }
            }

            //如果还有倒仓，继续调自己的数据
            show(manyList.get(0).getIntoStorehouse(), manyList.get(0).getIntoWarehouse(), orgId, listAll);
        }
    }

    /**
     * 查看粮情卡
     *
     * @param id
     * @param orgId
     * @return
     */
    @Override
    public List<StorageQualitycheckCard> findQuailckCardList(String id, String orgId) {
        StorageQualitycheckCard qualitycheckCard = new StorageQualitycheckCard();
        if (StringUtils.isNotBlank(id)) {
            qualitycheckCard.setQuailtyCardId(id);
        }
        if (StringUtils.isNotBlank(orgId)) {
            qualitycheckCard.setOrgId(Integer.valueOf(orgId));
        }
        return qualitycheckMapper.selectQuailckCardList(qualitycheckCard);
    }

    /**
     * 根据id获取原粮粮情卡数据.
     *
     * @param id
     * @return
     */
    @Override
    public StorageGrainCard findGrainCardById(String id) {
        return grainCardMapper.selectByPrimaryKey(id);
    }

    @Override
    public void saveGrainOilCardData(StorageGrainCard grainOil) {
        if (StringUtils.isBlank(grainOil.getId())) {
            // 入库数量不能为空,如果为空默认为 0
            if (null == grainOil.getRksl())
                grainOil.setRksl(new BigDecimal(0));
            // 添加id
            grainOil.setId(UuidUtils.getCode());
            grainOil.setFlagType("1"); // 保存:1,提交:2
            grainOil.setSfgd("1"); //是否归档新增时默认为1未归档，归档后为0
            grainCardMapper.insert(grainOil);

            // 生存告警数据
            generatorAlarm(grainOil);

            // 传给出入库数据List初始
            List<Map<String, Object>> wareList = new ArrayList<>();
            Map<String, Object> wareMap = new HashMap<>();
            wareMap.put("wareId", grainOil.getWarehouseId()); // 货位id
            wareMap.put("crk_status", "3"); // 出入库状态标记(1空仓,2入库中,3封仓,4出库中,9其它)
            wareMap.put("orgId", grainOil.getOrgId()); // 组织机构id
            wareMap.put("lylx", "0");//这里的默认都是原粮
            int str = grainOil.getStorehouseNum().indexOf("YG");
            if (str == -1 ) {
            	wareMap.put("ywlx", "0");//粮食
            } else {
            	wareMap.put("ywlx", "1");//油罐
            }
            wareList.add(wareMap);
            // list转字符串
            String wareJson = JSON.toJSONString(wareList);
            logger.info("传入库级basicWarehouse: " + wareJson);
            warehouseFeignClient.updateWarehouseCrkStatus(wareJson);
        } else {
            grainCardMapper.updateByPrimaryKeySelective(grainOil);
        }
    }

    /**
     * 查询质量检验生产年度
     *
     * @param houseId
     * @param orgId
     * @return
     */
    @Override
    public Map<String, Object> findQualityCheckScnd(Integer houseId, Integer warehouseId, String orgId, Integer parentId) {
        Map<String, Object> map = new HashMap<>();
        map.put("houseId", houseId);
        map.put("orgId", orgId);
        map.put("parentId", parentId);
        // 判断原油和原粮
        Map<String, Object> map1 = null;
        List<Map<String, Object>> list = null;
        if (parentId == 1061) { // 原粮油字典
            map.put("warehouseId", warehouseId);
            list = grainCardMapper.findQualityCheckScnd(map);
        } else { // 原油明细 7052
            list = grainCardMapper.findQualityCheckInfo(map);
        }
        if (null != list && list.size() > 0) {
            map1 = list.get(0);
        }
        return map1;
    }

    @Override
    @Transactional(isolation = Isolation.SERIALIZABLE)
    public void gainOilCardAllDelete(String id, String orgId) {
        // 复用查询条件
        Map<String, Object> map = mapCondition(id, orgId);
        // 先查询质量检验主表id,级联子表
        Integer qualityCheckId = grainCardMapper.joinQualityCheckId(map);
        /*
         * 删除信息必须全部为未提交信息,有一个已提交,全部不能删除,标记类型(保存:1,提交:2)
         */
        // 删除卡主表信息
        grainCardMapper.deleteByPrimaryKey(id);
        // 删除质量检验主表信息
        grainCardMapper.deleteQualityCheck(map);
        // 删除质量检验子表信息
        if (null != qualityCheckId)
            grainCardMapper.deleteQualityCheckInspection(qualityCheckId);
        // 删除水分检验信息
        grainCardMapper.deleteWaterDetailed(map);
        // 删除温度信息
        grainCardMapper.deleteTempCard(map);
        // 删除日常信息
        grainCardMapper.deleteDailyCheck(map);
    }

    @Override
    public void updateGainOilCardFlagType(String id) {
        StorageGrainCard grainCard = new StorageGrainCard();
        grainCard.setId(id);
        grainCard.setFlagType("2"); // 保存:1,提交:2
        grainCardMapper.updateByPrimaryKeySelective(grainCard);
    }

    @Override
    public List<StorageGrainCard> selectAndOrgId(String orgId) {
        // 查询所有条件数据
        StorageGrainCardExample grainCardExample = new StorageGrainCardExample();
        StorageGrainCardExample.Criteria criteria = grainCardExample.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        criteria.andSfgdEqualTo("1");
        List<StorageGrainCard> storageGrainCards = grainCardMapper.selectByExample(grainCardExample);
        return storageGrainCards;
    }

    @Override
    public void updateByExampleSelective(StorageGrainCard graincard) {

        /* 这是修改条件 */
        StorageGrainCardExample example = new StorageGrainCardExample();
        StorageGrainCardExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(graincard.getOrgId());
        criteria.andIdNotEqualTo(graincard.getId()); //不要这个ID对应的数据
        criteria.andStorehouseIdEqualTo(graincard.getStorehouseId());
        criteria.andWarehouseIdEqualTo(graincard.getWarehouseId());
        criteria.andSfgdEqualTo("1");

        /* 这是要修改的目标值 */
        StorageGrainCard card_new = new StorageGrainCard();
        card_new.setSfgd("0");
        card_new.setGdsj(new Date());
        grainCardMapper.updateByExampleSelective(card_new, example);
    }

    private Map<String, Object> mapCondition(String id, String orgId) {
        Map<String, Object> map = new HashMap<>();
        map.put("cardNum", id);
        map.put("orgId", orgId);
        return map;
    }

    /**
     * 获取粮情卡对应的自检入库验收数据
     * @param scnf
     * @param lspzdm
     * @param orgId
     * @param houseId
     * @param warehouseId
     * @param ywlx
     * @return
     */
    private String getQualityCheckId(String scnf, String lspzdm, String orgId, Integer houseId, Integer warehouseId, String ywlx) {
        if (StringUtils.isNotBlank(scnf)) {
            scnf = scnf.trim();
            Map<String, Object> map = new HashMap<>();
            map.put("orgId", orgId);
            map.put("ywlx", ywlx);
            map.put("scnf", scnf);
            map.put("houseId", houseId);
            if ("0".equals(ywlx)) {//粮仓的，油罐的数据在storage_qualitycheck表中货位的值是空的
                map.put("warehouseId", warehouseId);
            }
            lspzdm = lspzdm.substring(0,3);
            map.put("lspz", EnumUtils.getEnum(lspzdm).getName());
            List<StorageGrainCard> l = grainCardMapper.quailtyCheckDataParmarkKey(map);
            if (null != l && l.size() > 0) {
                return l.get(0).getId();
            }
        }

        return null;
    }

}
